@@ -34,6 +34,7 @@ std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor,
     std::shared_ptr<Table> tbl;
     std::shared_ptr<t_gnode> gnode;
     std::uint32_t offset;
+    void* ptr = nullptr;
 
     // If the Table has already been created, use it
     if (table_initialized) {
@@ -42,6 +43,8 @@ std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor,
         gnode = tbl->get_gnode();
         offset = tbl->get_offset();
         is_update = (is_update || gnode->mapping_size() > 0);
+    } else {
+        pool = std::make_shared<t_pool>();
     }
 
     std::vector<std::string> column_names;
@@ -57,53 +60,57 @@ std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor,
     if (is_arrow && !is_delete) {
         py::bytes bytes = accessor.cast<py::bytes>();
         std::int32_t size = bytes.attr("__len__")().cast<std::int32_t>();
-        void * ptr = malloc(size);
+        ptr = malloc(size);
         std::memcpy(ptr, bytes.cast<std::string>().c_str(), size);
-        arrow_loader.initialize((uintptr_t)ptr, size);
+        {
+            PerspectiveScopedGILRelease acquire(pool->get_event_loop_thread_id());
+        
+            arrow_loader.initialize((uintptr_t)ptr, size);
 
-        // Always use the `Table` column names and data types on update.
-        if (table_initialized && is_update) {
-            auto gnode_output_schema = gnode->get_output_schema();
-            auto schema = gnode_output_schema.drop({"psp_okey"});
-            column_names = schema.columns();
-            data_types = schema.types();
+            // Always use the `Table` column names and data types on update.
+            if (table_initialized && is_update) {
+                auto gnode_output_schema = gnode->get_output_schema();
+                auto schema = gnode_output_schema.drop({"psp_okey"});
+                column_names = schema.columns();
+                data_types = schema.types();
 
-            auto data_table = gnode->get_table();
-            if (data_table->size() == 0) {
-                /**
-                 * If updating a table created from schema, a 32-bit int/float
-                 * needs to be promoted to a 64-bit int/float if specified in
-                 * the Arrow schema.
-                 */
-                std::vector<t_dtype> arrow_dtypes = arrow_loader.types();
-                for (auto idx = 0; idx < column_names.size(); ++idx) {
-                    const std::string& name = column_names[idx];
-                    bool can_retype = name != "psp_okey" && name != "psp_pkey" && name != "psp_op";
-                    bool is_32_bit = data_types[idx] == DTYPE_INT32 || data_types[idx] == DTYPE_FLOAT32;
-                    if (can_retype && is_32_bit) {
-                        t_dtype arrow_dtype = arrow_dtypes[idx];
-                        switch (arrow_dtype) {
-                            case DTYPE_INT64:
-                            case DTYPE_FLOAT64: {
-                                std::cout << "Promoting column `" 
-                                            << column_names[idx] 
-                                            << "` to maintain consistency with Arrow type."
-                                            << std::endl;
-                                gnode->promote_column(name, arrow_dtype);
-                            } break;
-                            default: {
-                                continue;
+                auto data_table = gnode->get_table();
+                if (data_table->size() == 0) {
+                    /**
+                     * If updating a table created from schema, a 32-bit int/float
+                     * needs to be promoted to a 64-bit int/float if specified in
+                     * the Arrow schema.
+                     */
+                    std::vector<t_dtype> arrow_dtypes = arrow_loader.types();
+                    for (auto idx = 0; idx < column_names.size(); ++idx) {
+                        const std::string& name = column_names[idx];
+                        bool can_retype = name != "psp_okey" && name != "psp_pkey" && name != "psp_op";
+                        bool is_32_bit = data_types[idx] == DTYPE_INT32 || data_types[idx] == DTYPE_FLOAT32;
+                        if (can_retype && is_32_bit) {
+                            t_dtype arrow_dtype = arrow_dtypes[idx];
+                            switch (arrow_dtype) {
+                                case DTYPE_INT64:
+                                case DTYPE_FLOAT64: {
+                                    std::cout << "Promoting column `" 
+                                                << column_names[idx] 
+                                                << "` to maintain consistency with Arrow type."
+                                                << std::endl;
+                                    gnode->promote_column(name, arrow_dtype);
+                                } break;
+                                default: {
+                                    continue;
+                                }
                             }
                         }
                     }
                 }
+                // Make sure promoted types are used to construct data table
+                auto new_schema = gnode->get_output_schema().drop({"psp_okey"});
+                data_types = new_schema.types();
+            } else {
+                column_names = arrow_loader.names();
+                data_types = arrow_loader.types();
             }
-            // Make sure promoted types are used to construct data table
-            auto new_schema = gnode->get_output_schema().drop({"psp_okey"});
-            data_types = new_schema.types();
-        } else {
-            column_names = arrow_loader.names();
-            data_types = arrow_loader.types();
         }
     } else if (is_update || is_delete) {
         /**
@@ -151,7 +158,6 @@ std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor,
     }
     
     if (!table_initialized) {
-        pool = std::make_shared<t_pool>();
         tbl = std::make_shared<Table>(pool, column_names, data_types, limit, index);
         offset = 0;
     }
@@ -174,9 +180,9 @@ std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor,
     data_table.init();
     std::uint32_t row_count;
     if (is_arrow) {
+        PerspectiveScopedGILRelease acquire(pool->get_event_loop_thread_id());
         row_count = arrow_loader.row_count();
         data_table.extend(arrow_loader.row_count());
-
         arrow_loader.fill_table(data_table, input_schema, index, offset, limit, is_update);
     } else if (is_numpy) {
         row_count = numpy_loader.row_count();
@@ -188,8 +194,12 @@ std::shared_ptr<Table> make_table_py(t_val table, t_data_accessor accessor,
         _fill_data(data_table, accessor, input_schema, index, offset, limit, is_update);
     }
 
+    if (is_arrow) {
+        free(ptr);
+    }
+
     // calculate offset, limit, and set the gnode
-    tbl->init(data_table, row_count, op, port_id);
+    tbl->init(data_table, row_count, op, port_id);    
 
     //pool->_process();
     return tbl;
