@@ -6,7 +6,7 @@
 # the Apache License 2.0.  The full license can be found in the LICENSE file.
 #
 
-from six import string_types
+from six import string_types, iteritems
 from datetime import date, datetime
 from .view import View
 from ._accessor import _PerspectiveAccessor
@@ -14,12 +14,15 @@ from ._callback_cache import _PerspectiveCallBackCache
 from ..core.exception import PerspectiveError
 from ._date_validator import _PerspectiveDateValidator
 from ._state import _PerspectiveStateManager
-from ._utils import _dtype_to_pythontype, _dtype_to_str
+from ._utils import (
+    _dtype_to_pythontype,
+    _dtype_to_str,
+    _str_to_pythontype,
+    _parse_expression_strings,
+)
 from .libbinding import (
     make_table,
-    get_table_computed_schema,
-    get_computed_functions,
-    get_computation_input_types,
+    validate_expressions,
     str_to_filter_op,
     t_filter_op,
     t_op,
@@ -97,10 +100,6 @@ class Table(object):
         """Remove the specified port from the underlying `gnode`."""
         self._table.remove_port()
 
-    def compute(self):
-        """Returns whether the computed column feature is enabled."""
-        return True
-
     def get_index(self):
         """Returns the Table's index column, or ``None`` if an index is not
         specified by the user."""
@@ -132,27 +131,6 @@ class Table(object):
         self.update(data)
         self._state_manager.call_process(self._table.get_id())
 
-    def get_computed_functions(self):
-        """Returns a dict of computed function metadata, where each value is a
-        dict that contains the following metadata:
-
-        - name
-        - label
-        - pattern
-        - computed_function_name: the name of the computed function
-        - input_type: the data type of input columns ("float"/"integer" and
-        "date"/"datetime" are interchangable)
-        - return_type: the return type of its output column
-        - group: a category for the function
-        - num_params: the number of input parameters
-        - format_function: an anonymous function used for naming new columns
-
-        """
-        computed_functions = get_computed_functions()
-        for value in computed_functions.values():
-            value["num_params"] = int(value["num_params"])
-        return computed_functions
-
     def size(self):
         """Returns the row count of the :class:`~perspective.Table`."""
         self._state_manager.call_process(self._table.get_id())
@@ -181,68 +159,49 @@ class Table(object):
                     schema[columns[i]] = _dtype_to_pythontype(types[i])
         return schema
 
-    def computed_schema(self, computed_columns=None, **kwargs):
-        """Returns a schema containing the column names and data types of
-        the ``computed_columns`` argument.
-
-        If any column has invalid input columns or invalid types, they
-        will not be included in the output schema and a warning will be
-        logged.
+    def validate_expressions(self, expressions, as_string=False):
+        """Returns an :obj:`dict` with two keys: "expression_schema", which is
+        a schema containing the column names and data types for each valid
+        expression in ``expressions``, and "errors", which is a dict of
+        expressions to error objects that contain additional metadata:
+        `error_message`, `line`, and `column`.
 
         Args:
-            computed_columns (:obj:`list`): A list of computed column
-                definitions to create a schema from.
+            expressions (:obj:`list`): A list of string expressions to validate
+                and create a schema from.
 
         Keyword Args:
-            as_string (:obj:`bool`): returns the data types as string
-                representations, if True
+            as_string (:obj:`bool`): If True, returns the data types as string
+                representations so they can be serialized.
         """
-        schema = {}
-        if computed_columns is None or len(computed_columns) == 0:
-            return schema
+        validated = {"expression_schema": {}, "errors": {}}
 
-        s = get_table_computed_schema(self._table, computed_columns)
-        columns = s.columns()
-        types = s.types()
-        as_string = kwargs.pop("as_string", False)
-        for i in range(0, len(columns)):
-            if as_string:
-                schema[columns[i]] = _dtype_to_str(types[i])
-            else:
-                schema[columns[i]] = _dtype_to_pythontype(types[i])
-        return schema
+        if len(expressions) == 0:
+            return validated
 
-    def get_computation_input_types(self, computed_function_name=None, **kwargs):
-        """Returns a list of accepted input types for the provided
-        ``computed_function_name``.
+        expressions = _parse_expression_strings(expressions)
+        validation_results = validate_expressions(self._table, expressions)
+        expression_schema = validation_results.get_expression_schema()
+        expression_errors = validation_results.get_expression_errors()
 
-        Args:
-            computed_function_name (:obj:`str`): A :obj:`str` computed function
-                name for which valid input types must be returned.
+        for (alias, dtype) in iteritems(expression_schema):
+            if not as_string:
+                dtype = _str_to_pythontype(dtype)
+            validated["expression_schema"][alias] = expression_schema[alias]
 
-        Keyword Args:
-            as_string (:obj:`bool`): returns the data types as string
-                representations, if True.
-        """
-        new_types = []
-        if computed_function_name is None:
-            return new_types
-        types = get_computation_input_types(computed_function_name)
-        as_string = kwargs.pop("as_string", False)
-        for i in range(0, len(types)):
-            if as_string:
-                new_types.append(_dtype_to_str(types[i]))
-            else:
-                new_types.append(_dtype_to_pythontype(types[i]))
-        return new_types
+        for (alias, error) in iteritems(expression_errors):
+            error_dict = {}
+            error_dict["error_message"] = error.error_message
+            error_dict["line"] = error.line
+            error_dict["column"] = error.column
 
-    def columns(self, computed=False):
+            validated["errors"][alias] = error_dict
+
+        return validated
+
+    def columns(self):
         """Returns the column names of this :class:`~perspective.Table`.
 
-        Keyword Args:
-            computed (:obj:`bool`): Whether to include computed columns in this
-                array. Defaults to False.
-
         Returns:
             :obj:`list`: a list of string column names
         """
@@ -408,7 +367,7 @@ class Table(object):
         aggregates=None,
         sort=None,
         filter=None,
-        computed_columns=None,
+        expressions=None,
     ):
         """Create a new :class:`~perspective.View` from this
         :class:`~perspective.Table` via the supplied keyword arguments.
@@ -448,14 +407,19 @@ class Table(object):
         self._state_manager.call_process(self._table.get_id())
 
         config = {}
+
+        if expressions is not None:
+            config["expressions"] = _parse_expression_strings(expressions)
+
         if columns is None:
             config["columns"] = self.columns()
-            if computed_columns is not None:
-                # append all computed columns if columns are not specified
-                for col in computed_columns:
-                    config["columns"].append(col["column"])
+
+            if expressions is not None:
+                for expression in config["expressions"]:
+                    config["columns"].append(expression[0])
         else:
             config["columns"] = columns
+
         if row_pivots is not None:
             config["row_pivots"] = row_pivots
         if column_pivots is not None:
@@ -466,8 +430,6 @@ class Table(object):
             config["sort"] = sort
         if filter is not None:
             config["filter"] = filter
-        if computed_columns is not None:
-            config["computed_columns"] = computed_columns
 
         view = View(self, **config)
         self._views.append(view._name)
