@@ -133,6 +133,17 @@ class TestView(object):
         paths = view.column_paths()
         assert paths == ["__ROW_PATH__", "a", "b"]
 
+    def test_view_column_path_one_numeric_names(self):
+        data = {
+            "a": [1, 2, 3],
+            "b": [1.5, 2.5, 3.5],
+            "1234": [5, 6, 7]
+        }
+        tbl = Table(data)
+        view = tbl.view(row_pivots=["a"], columns=["b", "1234", "a"])
+        paths = view.column_paths()
+        assert paths == ["__ROW_PATH__", "b", "1234", "a"]
+
     def test_view_column_path_two(self):
         data = {
             "a": [1, 2, 3],
@@ -317,26 +328,37 @@ class TestView(object):
             aggregates={"c": "avg", "a": "last"},
             columns=[]
         )
+        assert view.column_paths() == ["__ROW_PATH__"]
         assert view.to_records() == [
             {"__ROW_PATH__": []},
             {"__ROW_PATH__": [1]},
             {"__ROW_PATH__": [3]}
         ]
 
-    def test_view_aggregates_column_order(self):
+    def test_view_aggregates_default_column_order(self):
         '''Order of columns are entirely determined by the `columns` kwarg. If
-        it is not provided, order of columns is undefined behavior.'''
+        it is not provided, order of columns is default based on the order
+        of table.columns().'''
         data = [{"a": 1, "b": 2, "c": 3, "d": 4}, {"a": 3, "b": 4, "c": 5, "d": 6}]
         tbl = Table(data)
+        cols = tbl.columns();
         view = tbl.view(
             row_pivots=["a"],
-            aggregates={"c": "avg", "a": "last"},
-            columns=["a", "c"]
+            aggregates={"c": "avg", "a": "last"}
         )
 
-        order = ["__ROW_PATH__", "a", "c"]
+        order = ["__ROW_PATH__"] + cols
         assert view.column_paths() == order
 
+        # check that default aggregates have been applied
+        result = view.to_dict()
+        assert result["b"] == [6, 2, 4]
+        assert result["d"] == [10, 4, 6]
+
+        # and that specified aggregates are applied
+        assert result["a"] == [3, 1, 3]
+        assert result["c"] == [4, 3, 5]
+
     # row and column pivot paths
     def test_view_row_pivot_datetime_row_paths_are_same_as_data(self):
         """Tests row paths for datetimes in UTC. Timezone-related tests are
@@ -1552,41 +1574,29 @@ class TestView(object):
             tbl.view(row_pivots=["a"], column_pivots=["c"], filter=[["a", ">", 1]], aggregates={"a": "avg"}, sort=[["x", "desc"]])
         assert str(ex.value) == "Invalid column 'x' found in View sorts.\n"
 
-    def test_invalid_columns_not_in_computed_should_throw(self):
+    def test_invalid_columns_not_in_expression_should_throw(self):
         data = [{"a": 1, "b": 2, "c": "a"}, {"a": 3, "b": 4, "c": "b"}]
         tbl = Table(data)
         with raises(PerspectiveCppError) as ex:
             tbl.view(
-                columns=["x"],
-                computed_columns=[
-                    {
-                        "column": "abc",
-                        "computed_function_name": "exp",
-                        "inputs": ["a"]
-                    }
-                ]
+                columns=["abc", "x"],
+                expressions=['// abc \n 1 + 2']
             )
         assert str(ex.value) == "Invalid column 'x' found in View columns.\n"
 
-    def test_should_not_throw_valid_computed_columns(self):
+    def test_should_not_throw_valid_expression(self):
         data = [{"a": 1, "b": 2, "c": "a"}, {"a": 3, "b": 4, "c": "b"}]
         tbl = Table(data)
         view = tbl.view(
             columns=["abc"],
-            computed_columns=[
-                {
-                    "column": "abc",
-                    "computed_function_name": "uppercase",
-                    "inputs": ["c"]
-                }
-            ]
+            expressions=["// abc \n 'hello!'"]
         )
 
         assert view.schema() == {
             "abc": str
         }
 
-    def test_should_not_throw_valid_computed_columns_config(self):
+    def test_should_not_throw_valid_expression_config(self):
         data = [{"a": 1, "b": 2, "c": "a"}, {"a": 3, "b": 4, "c": "b"}]
         tbl = Table(data)
         view = tbl.view(
@@ -1598,76 +1608,9 @@ class TestView(object):
             filter=[["abc", "==", "A"]],
             row_pivots=["abc"],
             column_pivots=["abc"],
-            computed_columns=[
-                {
-                    "column": "abc",
-                    "computed_function_name": "uppercase",
-                    "inputs": ["c"]
-                }
-            ]
+            expressions=["// abc \n 'hello!'"]
         )
 
         assert view.schema() == {
             "abc": str
         }
-
-    def test_should_not_throw_ancestor_computed(self):
-        cc = [
-            {
-                "column": "exp(Discount)",
-                "computed_function_name": "exp",
-                "inputs": ["Discount"],
-            },
-            {
-                "column": "(Profit * exp(Discount))",
-                "computed_function_name": "*",
-                "inputs": ["Profit", "exp(Discount)"],
-            },
-            {
-                "column": "(Sales + (Profit * exp(Discount)))",
-                "computed_function_name": "+",
-                "inputs": ["Sales", "(Profit * exp(Discount))"],
-            },
-            {
-                "column": "(Profit * Discount)",
-                "computed_function_name": "*",
-                "inputs": ["Profit", "Discount"],
-            },
-            {
-                "column": "sqrt(Row ID)",
-                "computed_function_name": "sqrt",
-                "inputs": ["Row ID"],
-            },
-            {
-                "column": "((Profit * Discount) * sqrt(Row ID))",
-                "computed_function_name": "*",
-                "inputs": ["(Profit * Discount)", "sqrt(Row ID)"],
-            },
-            {
-                "column": "((Sales + (Profit * exp(Discount))) - ((Profit * Discount) * sqrt(Row ID)))",
-                "computed_function_name": "-",
-                "inputs": [
-                    "(Sales + (Profit * exp(Discount)))",
-                    "((Profit * Discount) * sqrt(Row ID))",
-                ],
-            },
-        ]
-
-        table = Table({
-            "Discount": [random.random() for i in range(10)],
-            "Profit": [random.random() for i in range(10)],
-            "Row ID": [random.random() for i in range(10)],
-            "Sales": [random.random() for i in range(10)],
-        })
-
-        view = table.view(
-            columns=["sqrt(Row ID)"],
-            filter=[["((Profit * Discount) * sqrt(Row ID))", ">", 0]],
-            sort=[["exp(Discount)", "desc"]],
-            aggregates={"sqrt(Row ID)": "avg"},
-            computed_columns=cc,
-            row_pivots=["((Sales + (Profit * exp(Discount))) - ((Profit * Discount) * sqrt(Row ID)))"],
-            column_pivots=["((Sales + (Profit * exp(Discount))) - ((Profit * Discount) * sqrt(Row ID)))"]
-        )
-
-        assert view.num_columns() == 20
